@@ -5,6 +5,9 @@ from __future__ import (
 from decimal import (
     Decimal,
 )
+from deprecated import (
+    deprecated,
+)
 from typing import (
     Type,
     TypeVar,
@@ -38,6 +41,7 @@ PrimitiveTVar = TypeVar(  # Deprecated use NotNonePrimTvar instead
 NotNonePrimTvar = TypeVar("NotNonePrimTvar", str, int, float, Decimal, bool)
 
 
+@deprecated("Replaced. Use `fa_purity.json_2.primitive.JsonPrimitive` instead")  # type: ignore[misc]
 def is_primitive(raw: _T) -> TypeGuard[Primitive]:
     if raw is None or isinstance(raw, PrimitiveTypesList):
         return True
