@@ -1,3 +1,6 @@
+from deprecated import (
+    deprecated,
+)
 from fa_purity.json.errors import (
     invalid_type,
 )
@@ -19,6 +22,7 @@ from typing import (
 _T = TypeVar("_T")
 
 
+@deprecated("Replaced. Use `fa_purity.json_2.primitive.JsonPrimitiveUnfolder` instead")  # type: ignore[misc]
 def to_primitive(
     raw: _T, prim_type: Type[NotNonePrimTvar]
 ) -> Result[NotNonePrimTvar, InvalidType]:
@@ -29,6 +33,7 @@ def to_primitive(
     )
 
 
+@deprecated("Replaced. Use `fa_purity.json_2.primitive.JsonPrimitiveUnfolder` instead")  # type: ignore[misc]
 def to_opt_primitive(
     raw: _T, prim_type: Type[NotNonePrimTvar]
 ) -> Result[Optional[NotNonePrimTvar], InvalidType]:
