@@ -5,6 +5,9 @@ from __future__ import (
 from dataclasses import (
     dataclass,
 )
+from deprecated import (
+    deprecated,
+)
 from fa_purity.frozen import (
     FrozenDict,
     FrozenList,
@@ -24,6 +27,7 @@ UnfoldedJVal = Union[
 _T = TypeVar("_T")
 
 
+@deprecated("Replaced. Use `fa_purity.json_2.value.JsonValue` instead")  # type: ignore[misc]
 @dataclass(frozen=True)
 class JsonValue:
     _value: UnfoldedJVal
