@@ -1,3 +1,6 @@
+from deprecated import (
+    deprecated,
+)
 from fa_purity.frozen import (
     FrozenDict,
     FrozenList,
@@ -34,10 +37,12 @@ from typing import (
 _T = TypeVar("_T")
 
 
+@deprecated("Replaced. Use `fa_purity.json_2.value.JsonValueFactory` methods instead")  # type: ignore[misc]
 def from_list(raw: Union[List[Primitive], FrozenList[Primitive]]) -> JsonValue:
     return JsonValue(tuple(JsonValue(item) for item in raw))
 
 
+@deprecated("Replaced. Use `fa_purity.json_2.value.JsonValueFactory` methods instead")  # type: ignore[misc]
 def from_dict(
     raw: Union[Dict[str, Primitive], FrozenDict[str, Primitive]]
 ) -> JsonValue:
@@ -46,6 +51,7 @@ def from_dict(
     )
 
 
+@deprecated("Replaced. Use `fa_purity.json_2.value.JsonValueFactory` methods instead")  # type: ignore[misc]
 def from_any(raw: _T) -> Result[JsonValue, InvalidType]:
     if is_primitive(raw):
         return Result.success(JsonValue(raw))
