@@ -4,6 +4,7 @@ from ._core import (
 )
 from ._factory import (
     JsonValueFactory,
+    UnfoldedFactory,
 )
 from ._transform import (
     Unfolder,
@@ -13,5 +14,6 @@ __all__ = [
     "JsonValue",
     "JsonObj",
     "JsonValueFactory",
+    "UnfoldedFactory",
     "Unfolder",
 ]
