@@ -3,9 +3,13 @@ from .core import (
     ResultE,
     UnwrapError,
 )
+from .factory import (
+    ResultFactory,
+)
 
 __all__ = [
     "UnwrapError",
     "Result",
     "ResultE",
+    "ResultFactory",
 ]
